package tu.kielce.pl.sqlinjectiondemo;

import javafx.scene.control.Alert;
import javafx.scene.control.Button;
import org.springframework.security.crypto.argon2.Argon2PasswordEncoder;

public class LoginManager {
    private final AuthenticationPanel authenticationPanel;
    private final Button loginButton = new Button("Login");
    private final QueryExecutor queryExecutor;
    private final QueryProvider queryProvider;

    public LoginManager(AuthenticationPanel panel, QueryProvider provider, QueryExecutor executor) {
        authenticationPanel = panel;
        this.queryProvider = provider;
        this.queryExecutor = executor;
        loginButton.setPrefSize(290,20);
    }
    public void setup() {
        loginButton.setOnAction(actionEvent -> {
            String login = authenticationPanel.getLogin();
            String hashedPassword = hashPassword(authenticationPanel.getPassword());
            queryProvider.setLogin(login);
            queryProvider.setHashedPassword(hashedPassword);
            boolean isUserAuthenticated = queryExecutor.executeSelectQuery();
            if(isUserAuthenticated) {
                displayOutcome(Alert.AlertType.CONFIRMATION, "Access Granted");
            } else {
                displayOutcome(Alert.AlertType.ERROR, "Access Denied");
            }
        });
    }
    private String hashPassword(String password) {
        Argon2PasswordEncoder encoder = new Argon2PasswordEncoder(0,64,1,15*1024,1);
        return encoder.encode(password);
    }

    private void displayOutcome(Alert.AlertType type, String message) {
        Alert alert = new Alert(type);
        alert.setTitle("Authentication");
        alert.setContentText(message);
        alert.show();
    }

    public Button getLoginButton() {
        return loginButton;
    }
}
